@@ -106,9 +106,9 @@ static int _test_config (YKP_CONFIG *cfg, YK_STATUS *st, int argc, char **argv)
 	const char *outfname = NULL;
 	bool verbose = false;
 	bool dry_run = false;
-	char keylocation = 0;
 	bool use_access_code = false;
-	unsigned char access_code[256];
+	char *access_code = NULL;
+	char *new_access_code = NULL;
 	bool autocommit = false;
 	int exit_code = 0;
 	int data_format = YKP_FORMAT_LEGACY;
@@ -124,6 +124,8 @@ static int _test_config (YKP_CONFIG *cfg, YK_STATUS *st, int argc, char **argv)
 	bool zap = false;
 
 	unsigned char scan_map[sizeof(SCAN_MAP)];
+	unsigned char device_info[128];
+	size_t device_info_len = 0;
 
 	int rc;
 
@@ -144,11 +146,13 @@ static int _test_config (YKP_CONFIG *cfg, YK_STATUS *st, int argc, char **argv)
 			    &infname, &outfname,
 			    &data_format, &autocommit,
 			    st, &verbose, &dry_run,
-			    access_code, &use_access_code,
-			    &keylocation, &ndef_type, ndef, &usb_mode, &zap,
+			    &access_code, &new_access_code,
+			    &ndef_type, ndef, &usb_mode, &zap,
 			    scan_map, &cr_timeout, &autoeject_timeout, &num_modes_seen,
-			    &exit_code);
+			    device_info, &device_info_len, &exit_code);
 
+	free(access_code);
+	free(new_access_code);
 	return rc;
 }
 
@@ -203,10 +207,10 @@ static void _test_config_slot1(void)
 	};
 
 	char *argv[] = {
-		"unittest", "-1",
+		"unittest", "-1", "-a", "h:00000000000000000000000000000000",
 		NULL
 	};
-	int argc = 2;
+	int argc = 4;
 
 	rc = _test_config(cfg, st, argc, argv);
 	_check_success(rc, cfg, expected, __LINE__);
@@ -295,9 +299,8 @@ static void _test_non_config_args(void)
 	const char *outfname = NULL;
 	bool verbose = false;
 	bool dry_run = false;
-	char keylocation = 0;
-	bool use_access_code = false;
-	unsigned char access_code[256];
+	char *access_code = NULL;
+	char *new_access_code = NULL;
 	bool autocommit = false;
 	int exit_code = 0;
 	int i;
@@ -314,6 +317,8 @@ static void _test_non_config_args(void)
 	bool zap = false;
 
 	unsigned char scan_map[sizeof(SCAN_MAP)];
+	unsigned char device_info[128];
+	size_t device_info_len = 0;
 
 	char *argv[] = {
 		"unittest", "-1", "-sout", "-iin", "-c313233343536", "-y", "-v",
@@ -339,19 +344,21 @@ static void _test_non_config_args(void)
 			    &infname, &outfname,
 			    &data_format, &autocommit,
 			    st, &verbose, &dry_run,
-			    access_code, &use_access_code,
-			    &keylocation, &ndef_type, ndef, &usb_mode, &zap,
+			    &access_code, &new_access_code,
+			    &ndef_type, ndef, &usb_mode, &zap,
 			    scan_map, &cr_timeout, &autoeject_timeout, &num_modes_seen,
-			    &exit_code);
+			    device_info, &device_info_len, &exit_code);
 	assert(rc == 1);
 	i = strcmp(infname, "in"); assert(i == 0);
 	i = strcmp(outfname, "out"); assert(i == 0);
-	i = memcmp(access_code, "123456", 6); assert(i == 0);
+	i = memcmp(access_code, "313233343536", 12); assert(i == 0);
 	assert(autocommit == true);
 	assert(verbose == true);
 
 	ykp_free_config(cfg);
 	free(st);
+	free(access_code);
+	free(new_access_code);
 }
 
 static void _test_oath_hotp_nist_160_bits(void)
