@@ -120,30 +120,7 @@ int yk_check_firmware_version(YK_KEY *k)
 
 int yk_check_firmware_version2(YK_STATUS *st)
 {
-	switch(st->versionMajor) {
-		case 0:
-			if(st->versionMinor == 9)
-				return 1;
-			break;
-		case 1:
-			if(st->versionMinor <= 3)
-				return 1;
-			break;
-		case 2:
-			if(st->versionMinor <= 5)
-				return 1;
-			break;
-		case 3:
-			if(st->versionMinor <= 4)
-				return 1;
-			break;
-		case 4:
-			if(st->versionMinor <= 3)
-				return 1;
-			break;
-	}
-	yk_errno = YK_EFIRMWARE;
-	return 0;
+	return 1;
 }
 
 int yk_get_status(YK_KEY *k, YK_STATUS *status)
@@ -267,6 +244,12 @@ static int _yk_write(YK_KEY *yk, uint8_t yk_cmd, unsigned char *buf, size_t len)
 	return stat.pgmSeq != seq;
 }
 
+int yk_write_device_info(YK_KEY *yk, unsigned char *buf, unsigned int len)
+{
+	return _yk_write(yk, SLOT_YK4_SET_DEVICE_INFO, buf, len);
+}
+
+
 int yk_write_command(YK_KEY *yk, YK_CONFIG *cfg, uint8_t command,
 		    unsigned char *acc_code)
 {
